@@ -3,7 +3,9 @@ module Extract (Module(..), extract) where
 
 import           Prelude hiding (mod, concat)
 import           Control.Monad
+#if __GLASGOW_HASKELL__ < 710
 import           Control.Applicative
+#endif
 import           Control.Exception
 import           Data.List (partition, isSuffixOf)
 import           Data.Maybe
@@ -38,7 +40,7 @@ import           GhcUtil (withGhc)
 import           Location hiding (unLoc)
 
 import           Util (convertDosLineEndings)
-import           Sandbox (getSandboxArguments)
+import           PackageDBs (getPackageDBArgs)
 
 -- | A wrapper around `SomeException`, to allow for a custom `Show` instance.
 newtype ExtractError = ExtractError SomeException
@@ -146,8 +148,8 @@ parse args = withGhc args $ \modules_ -> withTempOutputDir $ do
 -- those modules (possibly indirect).
 extract :: [String] -> IO [Module (Located String)]
 extract args = do
-  sandboxArgs <- getSandboxArguments
-  let args'  = args ++ sandboxArgs
+  packageDBArgs <- getPackageDBArgs
+  let args'  = args ++ packageDBArgs
   mods <- parse args'
   let docs = map (fmap (fmap convertDosLineEndings) . extractFromModule . tm_parsed_module) mods
 
